@@ -1,4 +1,4 @@
-import collections
+# pylint: disable=R0904
 import threading
 import time
 import traceback
@@ -135,7 +135,7 @@ class Action:
         if atUser != 0:
             content = macro.atUser(atUser) + '\n' + content
         if picMd5s:
-            if not isinstance(picMd5s, collections.Sequence):
+            if isinstance(picMd5s, str):
                 picMd5s = [picMd5s]
             return self.post(
                 'SendMsgV2',
@@ -416,6 +416,15 @@ class Action:
             },
         )
 
+    def poke(self, user: int, group=0):
+        """戳一戳，未设置群ID就是戳好友"""
+        payload = {"UserID": user, "GroupID": group}
+        if group == 0:
+            payload['Type'] = 0
+        else:
+            payload['Type'] = 1
+        return self.post('OidbSvc.0xed3_1', payload)
+
     ############获取############
     def getCookies(self) -> dict:
         """获取QQ相关cookie"""
@@ -656,14 +665,14 @@ class Action:
     ) -> dict:
         """基础请求方法, 提供部分提示信息，出错返回空字典，其他返回服务端响应结果"""
         if params is not None:
-            params = params.update({'funcname': funcname})
+            params.update({'funcname': funcname})
         else:
             params = {'funcname': funcname}
 
         # 发送请求
         try:
             self.lock.acquire()
-            threading.Timer(1, self.release_lock).start()
+            threading.Timer(2.5, self.release_lock).start()
             resp = self.c.request(
                 method, httpx.URL(url=path, params=params), json=payload
             )
@@ -687,7 +696,7 @@ class Action:
             return {}
 
         if data is None:
-            logger.error('返回为null')
+            logger.error('返回为null, 该类情况多数是因为响应超时或者该API不存在，或服务端操作超时(此时不代表未成功)')
             return {}
 
         # 返回码提示
