@@ -1,7 +1,6 @@
 # pylint: disable = too-many-instance-attributes, W0212
 import copy
 import functools
-import sys
 import traceback
 from collections.abc import Sequence
 from typing import Any, Callable, List, Optional, Tuple, Union
@@ -9,7 +8,7 @@ from typing import Any, Callable, List, Optional, Tuple, Union
 import socketio
 
 from botoy.config import Config
-from botoy.log import enble_log_file, logger
+from botoy.log import logger, logger_init
 from botoy.model import EventMsg, FriendMsg, GroupMsg
 from botoy.plugin import PluginManager
 from botoy.pool import WorkerPool
@@ -35,8 +34,8 @@ class Botoy:
     :param group_blacklist: 群黑名单, 此名单中的群聊消息不会被处理,默认为``空``
     :param friend_blacklist: 好友黑名单，此名单中的好友消息不会被处理，默认为``空``
     :param blocked_users: 用户黑名单，即包括群消息和好友消息, 该用户的消息都不会处理, 默认为``空``
-    :param log: 是否开启日志
-    :param log_file: 是否输出日志文件
+    :param log: 该参数控制控制台日志等级,为True输出INFO等级日志,为False输出EROOR等级的日志
+    :param log_file: 该参数控制日志文件开与关,为True输出INFO等级日志的文件,为False关闭输出日志文件
     """
 
     def __init__(
@@ -50,7 +49,7 @@ class Botoy:
         friend_blacklist: List[int] = None,
         blocked_users: List[int] = None,
         log: bool = True,
-        log_file: bool = True,
+        log_file: bool = False,
     ):
         if qq is not None:
             if isinstance(qq, Sequence):
@@ -60,7 +59,6 @@ class Botoy:
         else:
             self.qq = None
 
-        self.use_plugins = use_plugins
         self.config = Config(
             host, port, group_blacklist, friend_blacklist, blocked_users
         )
@@ -68,11 +66,8 @@ class Botoy:
         # 作为程序是否应该退出的标志，以便后续用到
         self._exit = False
 
-        if log:
-            if log_file:
-                enble_log_file()
-        else:
-            logger.disable(__name__)
+        # 日志
+        logger_init(log, log_file)
 
         # 消息接收函数列表
         # 这里只储存主体文件中通过装饰器或函数添加的接收函数
@@ -239,12 +234,11 @@ class Botoy:
             if not self._when_disconnected_do[1]:
                 self._when_disconnected_do = None
 
-    def close(self, status=0):
+    def close(self):
         # 如果先关线程池，当新消息进入时依然会调用submit方法,此时会报错
         self.socketio.disconnect()
         self.pool.shutdown(wait=False)
         self._exit = True
-        sys.exit(status)
 
     def run(self):
         logger.info('Connecting to the server...')
@@ -252,7 +246,7 @@ class Botoy:
             self.socketio.connect(self.config.address, transports=['websocket'])
         except Exception:
             logger.error(traceback.format_exc())
-            self.close(1)
+            self.close()
         else:
             try:
                 self.socketio.wait()
@@ -260,7 +254,7 @@ class Botoy:
                 pass
             finally:
                 print('bye~')
-                self.close(0)
+                self.close()
 
     ########################################################################
     # context distributor
@@ -270,21 +264,24 @@ class Botoy:
             *self._friend_msg_receivers,
             *self.plugMgr.friend_msg_receivers,
         ]:
-            self.pool.submit(f_receiver, copy.deepcopy(context))
+            distributive_context = copy.deepcopy(context)
+            self.pool.submit(f_receiver, distributive_context)
 
     def _group_context_distributor(self, context: GroupMsg):
         for g_receiver in [
             *self._group_msg_receivers,
             *self.plugMgr.group_msg_receivers,
         ]:
-            self.pool.submit(g_receiver, copy.deepcopy(context))
+            distributive_context = copy.deepcopy(context)
+            self.pool.submit(g_receiver, distributive_context)
 
     def _event_context_distributor(self, context: EventMsg):
         for e_receiver in [
             *self._event_receivers,
             *self.plugMgr.event_receivers,
         ]:
-            self.pool.submit(e_receiver, copy.deepcopy(context))
+            distributive_context = copy.deepcopy(context)
+            self.pool.submit(e_receiver, distributive_context)
 
     ########################################################################
     # message handler
