@@ -43,9 +43,10 @@ def get_cache_dir(dir_name: str) -> Path:
             main_dir = Path('.')
 
     cache_dir = main_dir / 'botoy-cache'
-    this_cache_dir = cache_dir / dir_name
     if not cache_dir.exists():
         cache_dir.mkdir()
+
+    this_cache_dir = cache_dir / dir_name
     if not this_cache_dir.exists():
-        this_cache_dir.mkdir()
+        os.makedirs(this_cache_dir)
     return this_cache_dir
